This crate provides the TypestateBuilder derive macro for generating a
typestate-pattern builder for structs.
This is the helper crate of typestate-builder.
Derive Macros
- Typestate
Builder - The
TypestateBuilderderive macro generates builder pattern code based on the typestate pattern. It provides compile-time guarantees that all necessary fields are initialized before building the final struct.